import { z } from 'zod';

export const loginSchema = z.object({
  pseudo: z.string({ required_error: "Nom d'utilisateur requis", })
    .trim()
    .min(1, { message: "Nom d'utilisateur requis" }),
  passwd: z.string({ required_error: 'Mot de passe requis' })
    .trim()
    .min(1, { message: 'Mot de passe requis' }),
});

export const registerSchema = z.object({
  email: z
    .string({
      required_error: 'Email requis'
    })
    .trim()
    .max(64, {
      message: 'Email trop long (max 64 caractères)'
    })
    .email({
      message: 'Email invalide'
    }),
  firstname: z.string()
    .trim(),
  lastname: z.string()
    .trim(),
  pseudo: z.string({
    required_error: 'Nom d\'utilisateur requis'
  }).trim(),
});


export const registerConfirmationSchema = z.object({
  email: z
    .string({
      required_error: 'Email requis'
    })
    .trim()
    .max(64, {
      message: 'Email trop long (max 64 caractères)'
    })
    .email({
      message: 'Email invalide'
    }),
  firstname: z.string()
    .trim(),
  lastname: z.string()
    .trim(),
  pseudo: z.string({
    required_error: 'Nom d\'utilisateur requis'
  }).trim(),
  passwd: z.string({
    required_error: 'Mot de passe requis'
  })
    .trim()
    .min(1, { message: 'Mot de passe requis' }),
  code: z.string({
    required_error: 'Code manquant'
  })
    .regex(/^[0-9]{4}$/, { message: 'Code invalide, il doit contenir 4 chiffres' })
    .trim(),
});

export const requestPasswordResetSchema = z.object({
  email: z.string({ required_error: 'Email requis' })
    .trim()
    .email({ message: 'Email invalide' })
    .min(1, { message: 'Email requis' })
});

export const resetPasswordSchema = z.object({
  email: z.string({ required_error: 'Email requis' })
    .trim()
    .email({ message: 'Email invalide' })
    .min(1, { message: 'Email requis' }),
  password: z.string({ required_error: 'Mot de passe requis' })
    .trim()
    .min(1, { message: 'Mot de passe requis' }),
    code: z.string({
      required_error: 'Code manquant'
    })
      .regex(/^[0-9]{4}$/, { message: 'Code invalide, il doit contenir 4 chiffres' }),
});
